@@ -10,10 +10,11 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
+import io
+
 import botocore
 import botocore.stub
 import pytest
-from botocore.compat import six
 from botocore.config import Config
 from botocore.stub import Stubber
 
@@ -244,7 +245,7 @@ class TestCopy(BaseTransferTest):
 class TestUploadFileobj(BaseTransferTest):
     def setUp(self):
         super().setUp()
-        self.contents = six.BytesIO(b'foo\n')
+        self.contents = io.BytesIO(b'foo\n')
 
     def stub_put_object(self):
         put_object_response = {
@@ -330,7 +331,7 @@ class TestUploadFileobj(BaseTransferTest):
 
     def test_multipart_upload(self):
         chunksize = 8 * (1024**2)
-        contents = six.BytesIO(b'0' * (chunksize * 3))
+        contents = io.BytesIO(b'0' * (chunksize * 3))
         self.stub_multipart_upload(num_parts=3)
         transfer_config = TransferConfig(
             multipart_chunksize=chunksize,
@@ -354,7 +355,7 @@ class TestDownloadFileobj(BaseTransferTest):
     def setUp(self):
         super().setUp()
         self.contents = b'foo'
-        self.fileobj = six.BytesIO()
+        self.fileobj = io.BytesIO()
 
     def stub_single_part_download(self):
         self.stub_head(content_length=len(self.contents))
@@ -400,7 +401,7 @@ class TestDownloadFileobj(BaseTransferTest):
                 "ETag": self.etag,
                 "ContentLength": len(contents),
                 "ContentType": "binary/octet-stream",
-                "Body": six.BytesIO(contents),
+                "Body": io.BytesIO(contents),
                 "ResponseMetadata": {"HTTPStatusCode": 200},
             }
         )
