@@ -20,6 +20,7 @@ import shutil
 import string
 import tempfile
 import threading
+from pathlib import Path
 
 from botocore.client import Config
 
@@ -69,6 +70,7 @@ def setup_module():
         'CreateBucketConfiguration': {
             'LocationConstraint': _DEFAULT_REGION,
         },
+        'ObjectOwnership': 'ObjectWriter',
     }
     try:
         s3.create_bucket(**params)
@@ -78,6 +80,7 @@ def setup_module():
         # final call as to whether or not the bucket exists.
         LOG.debug("create_bucket() raised an exception: %s", e, exc_info=True)
     waiter.wait(Bucket=_SHARED_BUCKET)
+    s3.delete_public_access_block(Bucket=_SHARED_BUCKET)
 
 
 def clear_out_bucket(bucket, region, delete_bucket=False):
@@ -386,6 +389,13 @@ class TestS3Transfers(unittest.TestCase):
 
         self.assertEqual(fileobj.getvalue(), b'beach')
 
+    def test_upload_via_path(self):
+        transfer = self.create_s3_transfer()
+        filename = self.files.create_file_with_size('path.txt', filesize=1024)
+        transfer.upload_file(Path(filename), self.bucket_name, 'path.txt')
+        self.addCleanup(self.delete_object, 'path.txt')
+        self.assertTrue(self.object_exists('path.txt'))
+
     def test_upload_below_threshold(self):
         config = boto3.s3.transfer.TransferConfig(
             multipart_threshold=2 * 1024 * 1024
@@ -396,7 +406,6 @@ class TestS3Transfers(unittest.TestCase):
         )
         transfer.upload_file(filename, self.bucket_name, 'foo.txt')
         self.addCleanup(self.delete_object, 'foo.txt')
-
         self.assertTrue(self.object_exists('foo.txt'))
 
     def test_upload_above_threshold(self):
